@@ -238,11 +238,11 @@ include("head.inc");
     }
 ?>
     <section class="col-xs-12">
-      <div class="content-box tab-content">
-        <form method="post">
+      <form method="post">
+        <div class="content-box tab-content __mb">
           <table class="table table-striped opnsense_standard_table_form">
             <tr>
-              <td style="width:22%"><strong><?=gettext("System");?></strong></td>
+              <td style="width:22%"><strong><?= gettext('System') ?></strong></td>
               <td style="width:78%; text-align:right">
                 <small><?=gettext("full help"); ?> </small>
                 <i class="fa fa-toggle-off text-danger"  style="cursor: pointer;" id="show_all_help_page"></i>
@@ -290,7 +290,7 @@ include("head.inc");
             <tr>
               <td><a id="help_for_language" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Language");?></td>
               <td>
-                <select name="language" class="selectpicker" data-size="10" data-style="btn-default" data-width="auto">
+                <select name="language" class="selectpicker" data-style="btn-default">
 <?php
                   foreach (get_locale_list() as $lcode => $ldesc):?>
                   <option value="<?=$lcode;?>" <?= $lcode == $pconfig['language'] ? 'selected="selected"' : '' ?>>
@@ -300,16 +300,14 @@ include("head.inc");
                   endforeach;?>
                 </select>
                 <div class="hidden" data-for="help_for_language">
-                  <strong>
-                    <?= gettext('Choose a language for the web GUI.') ?>
-                  </strong>
+                  <?= gettext('Choose a language for the web GUI.') ?>
                 </div>
               </td>
             </tr>
             <tr>
               <td><a id="help_for_theme" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Theme"); ?></td>
               <td>
-                <select name="theme" class="selectpicker" data-size="10" data-width="auto">
+                <select name="theme" class="selectpicker">
 <?php
                 foreach (glob('/usr/local/opnsense/www/themes/*', GLOB_ONLYDIR) as $file):
                   $file = basename($file);?>
@@ -320,20 +318,23 @@ include("head.inc");
                 endforeach; ?>
                 </select>
                 <div class="hidden" data-for="help_for_theme">
-                  <strong>
-                    <?= gettext('This will change the look and feel of the GUI.') ?>
-                  </strong>
+                  <?= gettext('This will change the look and feel of the GUI.') ?>
                 </div>
               </td>
             </tr>
+          </table>
+        </div>
+        <div class="content-box tab-content __mb">
+          <table class="table table-striped opnsense_standard_table_form">
             <tr>
-              <th colspan="2" style="vertical-align:top" class="listtopic"><?=gettext("Networking"); ?></th>
+              <td style="width:22%"><strong><?= gettext('Networking') ?></strong></td>
+              <td style="width:78%"></td>
             </tr>
             <tr>
               <td><a id="help_for_prefer_ipv4" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Prefer IPv4 over IPv6"); ?></td>
               <td>
                 <input name="prefer_ipv4" type="checkbox" id="prefer_ipv4" value="yes" <?= !empty($pconfig['prefer_ipv4']) ? "checked=\"checked\"" : "";?> />
-                <strong><?=gettext("Prefer to use IPv4 even if IPv6 is available"); ?></strong>
+                <?=gettext("Prefer to use IPv4 even if IPv6 is available"); ?>
                 <div class="hidden" data-for="help_for_prefer_ipv4">
                   <?=gettext("By default, if a hostname resolves IPv6 and IPv4 addresses ".
                                       "IPv6 will be used, if you check this option, IPv4 will be " .
@@ -402,9 +403,7 @@ include("head.inc");
               <td><a id="help_for_dnsservers_opt" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("DNS server options"); ?></td>
               <td>
                 <input name="dnsallowoverride" type="checkbox" value="yes" <?= $pconfig['dnsallowoverride'] ? 'checked="checked"' : '' ?>/>
-                <strong>
-                  <?=gettext("Allow DNS server list to be overridden by DHCP/PPP on WAN"); ?>
-                </strong>
+                <?=gettext("Allow DNS server list to be overridden by DHCP/PPP on WAN"); ?>
                 <div class="hidden" data-for="help_for_dnsservers_opt">
                   <?= gettext("If this option is set, DNS servers " .
                   "assigned by a DHCP/PPP server on WAN will be used " .
@@ -412,26 +411,32 @@ include("head.inc");
                   "However, they will not be assigned to DHCP and PPTP " .
                   "VPN clients.") ?>
                 </div>
-                <br/>
+              </td>
+            </tr>
+            </tr>
+              <td></td>
+              <td>
                 <input name="dnslocalhost" type="checkbox" value="yes" <?=$pconfig['dnslocalhost'] ? "checked=\"checked\"" : ""; ?> />
-                <strong>
-                  <?=gettext("Do not use the DNS Forwarder/Resolver as a DNS server for the firewall"); ?>
-                </strong>
+                <?= gettext('Do not use the local DNS service as a nameserver for this system') ?>
                 <div class="hidden" data-for="help_for_dnsservers_opt">
-                  <?=gettext("By default localhost (127.0.0.1) will be used as the first DNS server where the DNS Forwarder or DNS Resolver is enabled and set to listen on Localhost, so system can use the local DNS service to perform lookups. ".
+                  <?=gettext("By default localhost (127.0.0.1) will be used as the first nameserver when e.g. Dnsmasq or Unbund is enabled, so system can use the local DNS service to perform lookups. ".
                   "Checking this box omits localhost from the list of DNS servers."); ?>
                 </div>
               </td>
             </tr>
+          </table>
+        </div>
+        <div class="content-box tab-content">
+          <table class="table table-striped opnsense_standard_table_form">
             <tr>
-              <td></td>
+              <td style="width:22%"></td>
               <td>
                 <input name="Submit" type="submit" class="btn btn-primary" value="<?=gettext("Save");?>" />
               </td>
             </tr>
           </table>
-        </form>
-      </div>
+        </div>
+      </form>
     </section>
     </div>
   </div>
